@@ -7,11 +7,9 @@
 #[macro_use]
 extern crate log;
 
-mod state;
 mod store;
 pub(crate) mod utils;
 
-pub use state::*;
 pub use store::*;
 
 // Reexports
